@@ -9,6 +9,41 @@ palette = cycle(px.colors.qualitative.Plotly)
 import numpy as np
 import plotly.express as px
 
+def plot_multiple_drawdowns(data_df, column_names):
+    fig = make_subplots(rows=1, cols=1)
+    for column_name in column_names:
+        trace_sig = go.Scatter(
+            x=data_df.index,
+            y=data_df[column_name],
+            name="drawdown",
+            opacity=0.8)
+        fig.append_trace(trace_sig, row=1, col=1)
+    fig.update_layout(height=600, width=1600, title_text="Drawdown chart",showlegend=True)
+    fig.update_xaxes(rangeslider_visible=True)
+    return fig
+
+def plot_drawdown(data_df, column_name, error_message = 'no data'):
+    if data_df is None:
+        fig = make_subplots(rows=1, cols=1)
+        fig.update_layout(height=600, width=1000, title_text=error_message)
+        return fig
+    fig = make_subplots(rows=1, cols=1)
+    trace_sig = go.Scatter(
+        x=data_df.index,
+        y=data_df[column_name],
+        name="drawdown",
+        opacity=0.8)
+    fig.append_trace(trace_sig, row=1, col=1)
+    fig.update_layout(height=600, width=1600, title_text="Drawdown chart",showlegend=True,legend = dict(
+                orientation="h",
+                yanchor="bottom",
+                y=1.02,
+                xanchor="right",
+                x=1
+            ))
+    fig.update_xaxes(rangeslider_visible=True)
+    return fig
+
 def create_ohlc_figure(data_df, underlying):
     fig = go.Figure(data=go.Ohlc(x=data_df.index,
                                  open=data_df['open'],
